@@ -1,7 +1,5 @@
 # add labels to grouping and facet variables, if these
 # variables come from labelled data
-#' @importFrom sjlabelled get_labels set_labels
-#' @importFrom stats na.omit
 .add_labels_to_groupvariable <- function(mydf, original_model_frame, terms) {
   grp.lbl <- sjlabelled::get_labels(
     original_model_frame[[terms[2]]],
@@ -69,7 +67,6 @@
 
 # this method converts lavelled group variables
 # into factors with labelled levels
-#' @importFrom sjlabelled as_label
 .groupvariable_to_labelled_factor <- function(mydf) {
   mydf$group <-
     sjlabelled::as_label(
@@ -96,7 +93,6 @@
 
 
 # get labels from labelled data for axis titles and labels
-#' @importFrom sjlabelled get_label
 .get_axis_titles_and_labels <- function(original_model_frame, terms, fun, model_info, no.transform, type) {
   # Retrieve response for automatic title
   resp.col <- colnames(original_model_frame)[1]
@@ -104,7 +100,7 @@
   # check for family, and set appropriate scale-title
   # if we have transformation through effects-package,
   # check if data is on original or transformed scale
-  ysc <- get_title_labels(fun, model_info, no.transform, type)
+  ysc <- .get_title_labels(fun, model_info, no.transform, type)
 
   # set plot-title
   t.title <-
@@ -150,10 +146,12 @@
 }
 
 
-get_title_labels <- function(fun, model_info, no.transform, type) {
+.get_title_labels <- function(fun, model_info, no.transform, type) {
   ysc <- "values"
 
-  if (fun == "glm") {
+  if (!is.null(type) && type == "zi.prob") {
+    ysc <- "zero-inflation probabilities"
+  } else if (fun == "glm") {
     if (model_info$is_brms_trial)
       ysc <- "successes"
     else if (model_info$is_binomial || model_info$is_ordinal || model_info$is_multinomial)
