@@ -1,6 +1,6 @@
 .runThisTest <- Sys.getenv("RunAllggeffectsTests") == "yes"
 
-if (.runThisTest) {
+if (.runThisTest && getRversion() >= "3.6.0") {
 
   if (require("testthat") && require("ggeffects") && require("ordinal") && require("MASS")) {
 
@@ -14,7 +14,7 @@ if (.runThisTest) {
     test_that("ggeffect", {
       p <- ggeffect(m1, "Infl")
       expect_equal(p$predicted[1], 0.457877729905463, tolerance = 1e-3)
-      ggeffect(m1, c("Infl", "Type"))
+      expect_s3_class(ggeffect(m1, c("Infl", "Type")), "data.frame")
     })
 
     test_that("ggemmeans", {
